<?php
/*
Plugin Name: Header Image Rotator 
Plugin URI: http://www.mhough.com
Description: Displays a new header image in your blog based on different time variables. Simply create a folder called wp-contents/header-images/ and add as many picures as your heart desires.
Author: Matthew Hough
Version: 1.1
Author URI: http://www.mhough.com

This plugin was based on the "Header Randomizer" plugin by Lennart Groetzbach (http://www.lennartgroetzbach.de/blog/?p=1040). Thanks!

Copyright (C) 2007 Matthew Hough (matthew.hough@gmail.com)

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
*/ 

/* Check to see if options already exist in the database */
$swap_rate = get_option('swap_rate');
$header_id = get_option('header_id');

/* Add options if they does not already exist */
if($swap_rate == '') {
add_option('swap_rate', '1');
}
if($header_id == '') {
add_option('header_id', 'header');
}

/* Define Constants and variables*/
define('IMAGE_FOLDER', 'header-images/');
define('IMAGE_PATH', ABSPATH .'wp-content/'.IMAGE_FOLDER);
define('IMAGE_URI', get_option('siteurl').'/wp-content/'.IMAGE_FOLDER);
define('PLUGIN_URI', get_option('siteurl').'/wp-content/plugins/image-rotator/');

/* Functions */
function get_files($dir) {
	$dh  = opendir($dir);
while (false !== ($filename = readdir($dh))) {
	$files[] = $filename;
}
$entries = array();
	if (is_dir($dir)) {
		foreach($files as $entry) {
			if($entry != '.' && $entry != '..') {
				$entries[] = $entry;
			}
		}
	}
	return $entries;
}

function rotator_admin_menu() {
   add_submenu_page('options-general.php', 'Header Image Rotator', 'Header Image Rotator', 8, __FILE__, 'rotator_options');
}

function image_swap($sr) {
	$ent_temp = get_files(IMAGE_PATH);
	$count = count($ent_temp);
	$date = date($sr);
	$key = $date % $count;
	return IMAGE_URI . $ent_temp[$key];
	}
	
function image_swap_half_hour() {
	$ent_temp = get_files(IMAGE_PATH);
	$count = count($ent_temp);
	$total_minute = (date(G)* 60)+ (date(i));
	$curr_min = $total_minute / 30;
	$curr_min = floor($curr_min);
	$key = $curr_min % $count;
	return IMAGE_URI . $ent_temp[$key];
	}

function switch_image(){
	switch (get_option("swap_rate")) {
		case "0": //weekly
		return image_swap("W");

		case "1": //daily
		return image_swap("z");

		case "2": //hourly
		return image_swap("G");

		case "3": //half-hour
		return image_swap_half_hour();

		case "4": //minute
		return image_swap("i");
	}
}

function header_img_check() {
	$head_css = get_option('header_id');
	if($head_css == "header"){
		echo PLUGIN_URI.'img/ok.gif';
	} else {
		echo PLUGIN_URI.'img/error.gif';
	}
}

function image_path_check() {
	$pics = count(get_files(IMAGE_PATH));
	if(is_dir(IMAGE_PATH)&& $pics != 0){
		echo PLUGIN_URI.'img/ok.gif';
	} else {
		echo PLUGIN_URI.'img/error.gif';
	}
}

function image_path_message() {
	$dir = is_dir(IMAGE_PATH);
	$pics = count(get_files(IMAGE_PATH)); 
	if(!$dir){
		echo "<font color=\"red\">The image directory has not been created or cannot be found. Please double check to make sure you have created the folder.</font>";
	} elseif($pics == 0) {
		echo "<font color=\"red\">There are no pictures in your image folder. Please add some images for the plugin to work.</font>";
	} else {
		echo "This is the folder where your header images are located.";
	}
}

function hir_add_css(){
	$img = switch_image();
	$headerID = get_option('header_id');
	print 
	<<<EOT
	<script type="text/javascript" language="javascript">
	var img = new Image();
	img.src = '$img';
	</script>
	<style type="text/css">
	#$headerID {
    background: url('$img') no-repeat;
    background-position: top center;    
	}
	</style>
EOT;
}

function hir_add_js() {
	print <<<EOT
	<script type="text/javascript">
	<!--
    function open_win(url, name, args) {
        newWindow = window.open(url, name, args);
        newWindow.screenX = window.screenX;
        newWindow.screenY = window.screenY;
        newWindow.focus();
    }
	//-->
	</script>
EOT;
}

function rotator_options() {
	if(isset($_POST['swap_rate'])){
		update_option("swap_rate", ($_POST["swap_rate"]));
	}
	if (isset($_POST['header_id'])){
		update_option("header_id", ($_POST['header_id']));
	}
	if (isset($_GET['to_del'])) {
	        @unlink(IMAGE_PATH. $_GET['to_del']);
	}
?>
<div class="wrap">
<form method="post">	
<h2>General Settings</h2>
	<table border="0" cellspacing="2" cellpadding="0">
		<tr>
			<td width="20"><img src="<?php echo PLUGIN_URI.'img/ok.gif'; ?>"</td>
			<td><b>Swap rate:</b></td>
			<td>
				<select name="swap_rate">
					<option <?php if(get_option('swap_rate') == "4") { echo "selected"; } ?> value="4">Minute</option>
					<option <?php if(get_option('swap_rate') == "3") { echo "selected"; } ?> value="3">Half-Hour</option>
					<option <?php if(get_option('swap_rate') == "2") { echo "selected"; } ?> value="2">Hourly</option>
					<option <?php if(get_option('swap_rate') == "1") { echo "selected"; } ?> value="1">Daily</option>
					<option <?php if(get_option('swap_rate') == "0") { echo "selected"; } ?> value="0">Weekly</option>
				</select>
				</td>
		</tr>
	</table>
	<table border="0" cellspacing="2" cellpadding="0">
		<tr>
			<td width="20"></td>
			<td>This setting determines the interval at which your header images rotate.</td>
		</tr>
	</table>
	<p></p>
	<table border="0" cellspacing="2" cellpadding="0">
		<tr>
			<td width="20"><img src="<?php header_img_check(); ?>"></td>
			<td><b>CSS header ID tag</b>:</td>
			<td><input type="text" name="header_id" size="24" border="0" value="<?php echo get_option('header_id'); ?>"></td>
		</tr>
	</table>
	<table border="0" cellspacing="2" cellpadding="0">
		<tr>
			<td width="20"></td>
			<td>This must read as &quot;header&quot; (without the quote marks) for the plugin to work. If anything else is listed above, change it back to 'header' and update.</td>
		</tr>
	</table>
	<p></p>
	<table border="0" cellspacing="2" cellpadding="0">
		<tr>
			<td width="20"><img src="<?php image_path_check(); ?>" alt=""></td>
			<td><b>Image path:</b></td>
			<td>/wp-content/header-images/</td>
		</tr>
	</table>
	<table border="0" cellspacing="2" cellpadding="0">
		<tr>
			<td width="20"></td>
			<td><?php image_path_message(); ?></td>
		</tr>
	</table>
		<p><input type="submit" name="submitButtonName" value="Update" border="0"></p>
</form>
	
<h3>Images</h3>
	<ul>
	<?php $image_array = (get_files(IMAGE_PATH));
		foreach($image_array as $entry){
		echo '<li><a href="javascript:void(0)" onClick="open_win(\''.IMAGE_URI.$entry.'\', \'header\', \'width=500,height=250,status=no,toolbar=no,menubar=no,scrollbars=yes,resizable=yes\')">'.$entry . '</a> <a href="'. $_SERVER["REQUEST_URI"].'&to_del='.$entry.'" title="delete file" >[X]</a></li>';
		}
	?>
	</ul>
</div>
<?php
}

/* Add actions */
add_action('admin_menu', 'rotator_admin_menu');
add_action('admin_head', 'hir_add_js');

/* Check for correct initialization, if not found, don't add css */
if(is_dir(IMAGE_PATH) && count(get_files(IMAGE_PATH)) > 0) {
	add_action('wp_head', 'hir_add_css');
}

?>
